<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ast">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Calca nel iconu de la bandexa o volvi
primir nel atayu pa dexar de grabar</translation>
    </message>
    <message>
        <source>Do not rotate your screen during recording</source>
        <translation>No rotéis la pantalla durante la grabación</translation>
    </message>
</context>
<context>
    <name>IconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Captura de pantalla</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>Grabación</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation>Grabar</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Captura de pantalla</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Captura de pantalla</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>El salvu faló. Por favor, guárdalo en el directoriu de tu home</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>Captura de pantalla terminada</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>seleccionar área</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Salvar</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Guardado en %1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorar</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Cartafueyu</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>Guardando el archivo de grabación de pantalla, por favor espera...</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>Como l&apos;efectu de ventana ta desactiváu durante el proceso, la grabación tiene de ser parada</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Captura de pantalla</translation>
    </message>
    <message>
        <source>Screenshot failed.</source>
        <translation>Captura de pantalla faló.</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Scrollshot</translation>
    </message>
    <message>
        <source>Pin Screenshots</source>
        <translation>Pegar capturas de pantalla</translation>
    </message>
    <message>
        <source>deepin-screen-recorder</source>
        <translation>deepin-screen-recorder</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Abrir carpeta</translation>
    </message>
    <message>
        <source>Screenshot finished and copy to clipboard</source>
        <translation>Captura de pantalla terminada y copiada al portapapeles</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Deshacer</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Salvar</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Salir</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Pin Screenshots</source>
        <translation>Pegar capturas de pantalla</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Captura de pantalla</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Grabar</translation>
    </message>
</context>
<context>
    <name>RecordIconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Captura de pantalla</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>Grabación</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>Finó la grabación</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Guardáu en %1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Grabar</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Abrir carpeta</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>La captura de pantalla empezará en %1 segundos</translation>
    </message>
</context>
<context>
    <name>ScrollShotTip</name>
    <message>
        <source>Get help.</source>
        <translation>Consulter ayuda.</translation>
    </message>
    <message>
        <source>Failed to take a continuous screenshot.</source>
        <translation>Falló na toma d&apos;una captura continua.</translation>
    </message>
    <message>
        <source>Reached the bottom of the scroll area</source>
        <translation>Llegáu al final de l&apos;área de desplazamiento</translation>
    </message>
    <message>
        <source>Reached the maximum length</source>
        <translation>Llegáu al llargor máximo</translation>
    </message>
    <message>
        <source>adjust the capture area</source>
        <translation>Ajusta l&apos;área de captura</translation>
    </message>
    <message>
        <source>Scroll your mouse wheel or click to take a scrolling screenshot</source>
        <translation>Desplázate col ruedu del ratón o clicar pa tomar una captura de pantalla desplazable</translation>
    </message>
    <message>
        <source>Slow down the scrolling speed</source>
        <translation>Amorrece la velocidá de desplazamiento</translation>
    </message>
    <message>
        <source>Invalid area, click to </source>
        <translation>Área inválida, clicar pa </translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Introduzir texto aquí</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Empezar/Captura</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Salir/Guardar</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Ajuste de tamaño</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Axustes</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Aniciu rápidu</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Captura de ventanu</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Retardar captura</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Captura completa</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Salir</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rectángulu</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elipse</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Llinia</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Llápiz</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Texto</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Desfacer</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Aumentar altura arriba</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Aumentar altura abaxo</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Aumentar anchura izquierda</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Aumentar anchura derecha</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Decreseyar altura arriba</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Decreseyar altura abaxo</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Reducir anchura izquierda</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Reducir anchura derecha</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Mostrar atajos</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Son</translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation>Atajo</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Cámara web</translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>Aniciar la grabación</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opciones</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation>Empezar/Grabar</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Mur</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Herramientas</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Extraer texto</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Scrollshot</translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation>Pegar capturas de pantalla</translation>
    </message>
    <message>
        <source>Start OCR</source>
        <translation>Empezar OCR</translation>
    </message>
    <message>
        <source>Start scrollshot</source>
        <translation>Empezar scrollshot</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Flecha</translation>
    </message>
</context>
<context>
    <name>ShotStartPlugin</name>
    <message>
        <source>Screenshot</source>
        <translation>Captura de pantalla</translation>
    </message>
</context>
<context>
    <name>ShotStartRecordPlugin</name>
    <message>
        <source>Record</source>
        <translation>Grabar</translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Rectangle
Press and hold Shift to draw a square</source>
        <translation>Rectángulu
Presione y sosténgase Shift pa dibuxar un cuadráu</translation>
    </message>
    <message>
        <source>Ellipse
Press and hold Shift to draw a circle</source>
        <translation>Elipsa
Presione y sosténgase Shift pa dibuxar un círculu</translation>
    </message>
    <message>
        <source>Brush
Press and hold Shift to draw a straight line</source>
        <translation>Pincel
Presione y sosténgase Shift pa dibuxar una línea recta</translation>
    </message>
    <message>
        <source>Adjust blur strength (Scroll to adjust it)</source>
        <translation>Ajustar intensidá de desenfocu (Desplázese pa ajustalo)</translation>
    </message>
    <message>
        <source>Adjust brush size (Scroll to adjust it)</source>
        <translation>Ajustar tamaño del pincel (Desplázese pa ajustalo)</translation>
    </message>
    <message>
        <source>Adjust text size (Scroll to adjust it)</source>
        <translation>Ajustar tamaño del texto (Desplázese pa ajustalo)</translation>
    </message>
</context>
<context>
    <name>StartTooltip</name>
    <message>
        <source>Click or drag to
select the area to record</source>
        <translation>Calca o arrastra pa
esbillar l&apos;área a grabar</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Show keystroke (K)</source>
        <translation>Mostrar atajo (K)</translation>
    </message>
    <message>
        <source>Hide Keystroke (K)</source>
        <translation>Esconder atajo (K)</translation>
    </message>
    <message>
        <source>Show Keystroke (K)</source>
        <translation>Mostrar atajo (K)</translation>
    </message>
    <message>
        <source>Turn on camera (C)</source>
        <translation>Activar camara (C)</translation>
    </message>
    <message>
        <source>Turn off camera (C)</source>
        <translation>Desactivar camara (C)</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Captura de pantalla</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Axustes</translation>
    </message>
    <message>
        <source>Settings (F3)</source>
        <translation>Configuración (F3)</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Formato:</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>webm</source>
        <translation>webm</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>FPS:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 إطار في الثانية</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 إطار في الثانية</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 إطار في الثانية</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 إطار في الثانية</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 إطار في الثانية</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>الصوت</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>الميكروفون</translation>
    </message>
    <message>
        <source>System audio</source>
        <translation>الصوت النظامي</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opciones</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>عرض المؤشر</translation>
    </message>
    <message>
        <source>Show click</source>
        <translation>عرض النقر</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>احفظ إلى</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Escritoriu</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>الفيديوهات</translation>
    </message>
    <message>
        <source>Rectangle (R)
Press and hold Shift to draw a square</source>
        <translation>مستطيل (R)
اضغط واحفظ Shift لرسم مربع</translation>
    </message>
    <message>
        <source>Ellipse (O)
Press and hold Shift to draw a circle</source>
        <translation>橢圓形 (O)
اضغط واحفظ Shift لرسم دائرة</translation>
    </message>
    <message>
        <source>Line (L)
Press and hold Shift to draw a vertical or horizontal line</source>
        <translation>خط (L)
اضغط واحفظ Shift لرسم خط عمودي أو أفقي</translation>
    </message>
    <message>
        <source>Arrow (X)
Press and hold Shift to draw a vertical or horizontal arrow</source>
        <translation>سهم (X)
اضغط واحفظ Shift لرسم سهم عمودي أو أفقي</translation>
    </message>
    <message>
        <source>Pencil (P)</source>
        <translation>قلم (P)</translation>
    </message>
    <message>
        <source>Blur (B)</source>
        <translation>الإبهام (B)</translation>
    </message>
    <message>
        <source>Text (T)</source>
        <translation>النص (T)</translation>
    </message>
    <message>
        <source>Scrollshot (Alt+I）</source>
        <translation>شاشة التمرير (Alt+I)</translation>
    </message>
    <message>
        <source>Extract text (Alt+O）</source>
        <translation>استخراج النص (Alt+O)</translation>
    </message>
    <message>
        <source>Pin screenshots (Alt+P）</source>
        <translation>الصق صور الشاشة (Alt+P)</translation>
    </message>
    <message>
        <source>Undo (Ctrl+Z)</source>
        <translation>الإلغاء (Ctrl+Z)</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>تسجيل</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Cartafueyu</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Semeyes</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Carpeta</translation>
    </message>
    <message>
        <source>Set a path on save</source>
        <translation>تحديد مسار عند الحفظ</translation>
    </message>
    <message>
        <source>Change the path on save</source>
        <translation>تغيير المسار عند الحفظ</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>التنسيق</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>Border Effects</source>
        <translation>تأثيرات الحدود</translation>
    </message>
    <message>
        <source>None</source>
        <translation>لا شيء</translation>
    </message>
    <message>
        <source>Shadow</source>
        <translation>ظلال</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>الحدود</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>الجهاز</translation>
    </message>
    <message>
        <source>Extract Text</source>
        <translation>استخراج النص</translation>
    </message>
</context>
<context>
    <name>ToolBarWidget</name>
    <message>
        <source>Close (Esc)</source>
        <translation>Cerrar (Esc)</translation>
    </message>
    <message>
        <source>OK (Enter)</source>
        <translation>موافق (Enter)</translation>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation>Ajusta l&apos;área de grabación dientro de %1*%2 pa obtener un efectu de vídeo mellor</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Screen recording is not supported at present</source>
        <translation>La grabación de pantalla nun ta soportada actualmente</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Salir</translation>
    </message>
</context>
<context>
    <name>VoiceRecordProcess</name>
    <message>
        <source>New recording</source>
        <translation>Grabación nueva</translation>
    </message>
</context>
</TS>
